On Feb 5, 10:44 pm, Alessio Sangalli <[email protected]> wrote:

> > I'd start by rewriting functors to use integer instead of float. For
> > making it even simpler I'd remove all functors used for determining
> > weight except for ExposureFunctor (by default it has highest weight
> > and for blending exposure is usually the most important measure).
>
> OK; is this done while "loading" the image?

I was indeed able to reduce the time to "load" the images
drammatically; I have not done many tests but if before the time was
(depending on the size of the images I was testing with) between 20
and 30s, now it's about one or two seconds each.

The interesting thing is that I noticed that in function:
gaussDistribution(double x, double mu, double sigma)
the arguments mu and sigma were always 0, probably due to the int
conversion, so I commented out the gaussDistribution call entirely...
and I do not see any "visual" difference against the images calculated
in full FP (double) mode.


Right now my enfusion test case runs in about 0:47s down from the
original 1:36s

bye
as

-- 
You received this message because you are subscribed to the Google Groups 
"Hugin and other free panoramic software" group.
A list of frequently asked questions is available at: 
http://wiki.panotools.org/Hugin_FAQ
To post to this group, send email to [email protected]
To unsubscribe from this group, send email to 
[email protected]
For more options, visit this group at http://groups.google.com/group/hugin-ptx

Reply via email to